package org.kantega.jexmec.test;

/*
 * Copyright 2011 Kantega AS
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import org.kantega.jexmec.PluginClassLoaderProvider;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 *
 */
public class TestRegistry implements PluginClassLoaderProvider.Registry {
    private final List<ClassLoader> classLoaders = new ArrayList<ClassLoader>();
    private final List<ClassLoader> addedClassLoaders = new ArrayList<ClassLoader>();
    private final List<ClassLoader> removedClassLoaders = new ArrayList<ClassLoader>();

    public <T extends ClassLoader> void add(Iterable<T> classLoaders) {
        replace(Collections.<T>emptySet(), classLoaders);
    }

    public <T extends ClassLoader> void remove(Iterable<T> loaders) {
        replace(loaders, Collections.<T>emptySet());
    }

    public <T extends ClassLoader> void replace(final Iterable<T> removeClassLoaders, Iterable<T> addClassLoaders) {

        for (T c : addClassLoaders) {
            classLoaders.add(c);
            addedClassLoaders.add(c);
        }

        for (T c : removeClassLoaders) {
            classLoaders.remove(c);
            removedClassLoaders.add(c);
        }

    }

    public List<ClassLoader> getClassLoaders() {
        return classLoaders;
    }

    public List<ClassLoader> getAddedClassLoaders() {
        return addedClassLoaders;
    }

    public List<ClassLoader> getRemovedClassLoaders() {
        return removedClassLoaders;
    }
}
